@@ -4,6 +4,7 @@ from __future__ import absolute_import
 
 # import apis into api package
 from pulpcore.client.pulp_ansible.api.ansible_collections_api import AnsibleCollectionsApi
+from pulpcore.client.pulp_ansible.api.ansible_copy_api import AnsibleCopyApi
 from pulpcore.client.pulp_ansible.api.api_collections_api import ApiCollectionsApi
 from pulpcore.client.pulp_ansible.api.api_roles_api import ApiRolesApi
 from pulpcore.client.pulp_ansible.api.collection_import_api import CollectionImportApi
@@ -15,7 +16,6 @@ from pulpcore.client.pulp_ansible.api.pulp_ansible_api_api import PulpAnsibleApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_collections_api import PulpAnsibleGalaxyApiCollectionsApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v2_versions_api import PulpAnsibleGalaxyApiV2VersionsApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_collections_api import PulpAnsibleGalaxyApiV3CollectionsApi
-from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_collections_certified_api import PulpAnsibleGalaxyApiV3CollectionsCertifiedApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_collections_docs_blob_api import PulpAnsibleGalaxyApiV3CollectionsDocsBlobApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_versions_api import PulpAnsibleGalaxyApiV3VersionsApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_tags_api import PulpAnsibleTagsApi
